@@ -40,7 +40,7 @@
 #include "dealerinfo.h"
 #include "patsolve/clocksolver.h"
 // KF
-#include <KLocalizedString>
+#include <KLazyLocalizedString>
 
 Clock::Clock(const DealerInfo *di)
     : DealerScene(di)
